@@ -143,11 +143,21 @@ public class O365InteractiveAuthenticator implements ExchangeAuthenticator {
 
         if (isSWTAvailable && !isDocker) {
             LOGGER.debug("Open SWT browser");
-            o365InteractiveAuthenticatorSWT = new O365InteractiveAuthenticatorSWT();
-            o365InteractiveAuthenticatorSWT.setO365InteractiveAuthenticator(O365InteractiveAuthenticator.this);
-            o365InteractiveAuthenticatorSWT.authenticate(initUrl, redirectUri);
-        } else if (isJFXAvailable) {
-            LOGGER.debug("Open OpenJFX browser");
+            try {
+                o365InteractiveAuthenticatorSWT = new O365InteractiveAuthenticatorSWT();
+                o365InteractiveAuthenticatorSWT.setO365InteractiveAuthenticator(O365InteractiveAuthenticator.this);
+                o365InteractiveAuthenticatorSWT.authenticate(initUrl, redirectUri);
+            } catch (Error e) {
+                LOGGER.warn("Unable to load SWT browser");
+                if (o365InteractiveAuthenticatorSWT != null) {
+                    o365InteractiveAuthenticatorSWT.dispose();
+                }
+                o365InteractiveAuthenticatorSWT = null;
+            }
+        }
+
+        if (o365InteractiveAuthenticatorSWT == null && isJFXAvailable) {
+            LOGGER.info("Open JavaFX (OpenJFX) browser");
             SwingUtilities.invokeLater(() -> {
                 try {
                     o365InteractiveAuthenticatorFrame = new O365InteractiveAuthenticatorFrame();
@@ -195,6 +205,10 @@ public class O365InteractiveAuthenticator implements ExchangeAuthenticator {
             o365InteractiveAuthenticatorFrame.close();
         }
 
+        if (o365InteractiveAuthenticatorSWT != null) {
+            o365InteractiveAuthenticatorSWT.dispose();
+        }
+
         if (isAuthenticated) {
             token = O365Token.build(tenantId, clientId, redirectUri, code, password);
 
