@@ -151,25 +151,13 @@ public class O365InteractiveAuthenticatorFrame extends JFrame {
                 LOGGER.debug("Webview location: " + location);
                 // override console.log
                 O365InteractiveJSLogger.register(webViewEngine);
-                if (LOGGER.isDebugEnabled()) {
+                if (Settings.getBooleanProperty("davmail.webview.debug", false)) {
                     LOGGER.debug(dumpDocument(webViewEngine.getDocument()));
                 }
                 if (location.startsWith(redirectUri)) {
                     LOGGER.debug("Location starts with redirectUri, check code");
+                    authenticator.handleCode(location);
 
-                    authenticator.isAuthenticated = location.contains("code=") && location.contains("&session_state=");
-                    if (!authenticator.isAuthenticated && location.contains("error=")) {
-                        authenticator.errorCode = location.substring(location.indexOf("error="));
-                    }
-                    if (authenticator.isAuthenticated) {
-                        LOGGER.debug("Authenticated location: " + location);
-                        String code = location.substring(location.indexOf("code=") + 5, location.indexOf("&session_state="));
-                        String sessionState = location.substring(location.lastIndexOf('='));
-
-                        LOGGER.debug("Authentication Code: " + code);
-                        LOGGER.debug("Authentication session state: " + sessionState);
-                        authenticator.code = code;
-                    }
                     close();
                 }
             } else if (newState == Worker.State.FAILED) {
