@@ -76,4 +76,20 @@ public class IndexedFieldURI implements FieldURI {
     public String getGraphId() {
         throw new UnsupportedOperationException();
     }
+
+    @Override
+    public boolean isMultiValued() {
+        return true;
+    }
+
+    @Override
+    public boolean isNumber() {
+        // TODO
+        throw new UnsupportedOperationException();
+    }
+
+    @Override
+    public boolean isBoolean() {
+        throw new UnsupportedOperationException();
+    }
 }
