@@ -28,6 +28,7 @@ import java.util.List;
 public class UnindexedFieldURI implements FieldURI {
     protected final String fieldURI;
     protected final String fieldName;
+    protected String graphId;
 
     /**
      * Create unindexed field URI.
@@ -44,6 +45,11 @@ public class UnindexedFieldURI implements FieldURI {
         }
     }
 
+    public UnindexedFieldURI(String fieldURI, String graphId) {
+        this(fieldURI);
+        this.graphId = graphId;
+    }
+
     public void appendTo(StringBuilder buffer) {
         buffer.append("<t:FieldURI FieldURI=\"").append(fieldURI).append("\"/>");
     }
@@ -156,8 +162,27 @@ public class UnindexedFieldURI implements FieldURI {
 
     @Override
     public String getGraphId() {
-        // todo check valid for other fields?
-        return fieldName;
+        if (graphId != null) {
+            return graphId;
+        } else {
+            return fieldName;
+        }
+    }
+
+    @Override
+    public boolean isMultiValued() {
+        return false;
+    }
+
+    @Override
+    public boolean isNumber() {
+        // TODO
+        throw new UnsupportedOperationException();
+    }
+
+    @Override
+    public boolean isBoolean() {
+        throw new UnsupportedOperationException();
     }
 
 }
