@@ -36,6 +36,7 @@ import java.security.NoSuchAlgorithmException;
 import java.security.SecureRandom;
 import java.security.cert.Certificate;
 import java.security.cert.CertificateEncodingException;
+import java.security.cert.X509Certificate;
 import java.util.Arrays;
 import java.util.Locale;
 
@@ -145,7 +146,6 @@ final class DavMailNTLMEngineImpl implements NTLMEngine {
      */
     static String getType1Message(final String host, final String domain) {
         // For compatibility reason do not include domain and host in type 1 message
-        //return new Type1Message(domain, host).getResponse();
         return TYPE_1_MESSAGE;
     }
 
@@ -1300,8 +1300,10 @@ final class DavMailNTLMEngineImpl implements NTLMEngine {
             if (peerServerCertificate != null) {
                 responseTargetInformation = addGssMicAvsToTargetInfo(targetInformation, peerServerCertificate);
                 computeMic = true;
+                LOGGER.debug("Included certificate info for channel binding subject:"+((X509Certificate)peerServerCertificate).getSubjectX500Principal());
             } else {
                 computeMic = false;
+                LOGGER.debug("Certificate info not available for channel binding");
             }
 
             // Create a cipher generator class.  Use domain BEFORE it gets modified!
@@ -1837,7 +1839,9 @@ final class DavMailNTLMEngineImpl implements NTLMEngine {
             final String domain,
             final String workstation) {
         LOGGER.debug("generateType1Msg domain='" + domain + "' workstation='" + workstation + "'");
-        return getType1Message(workstation, domain);
+        LOGGER.debug(NTLMMessageDecoder.decode(TYPE_1_MESSAGE));
+        // Type 1 message is a constant without domain and workstation
+        return TYPE_1_MESSAGE;
     }
 
     @Override
@@ -1851,12 +1855,15 @@ final class DavMailNTLMEngineImpl implements NTLMEngine {
         // need to retrieve raw type 1 and 2 message and connection certificate for channel binding implementation
         byte[] type1MessageBytes = new Type1Message().getBytes();
         byte[] type2MessageBytes = Base64.decodeBase64(challenge.getBytes(DEFAULT_CHARSET));
+        if (LOGGER.isDebugEnabled()) {
+            LOGGER.debug(NTLMMessageDecoder.decode(challenge));
+        }
 
         final DavMailNTLMEngineImpl.Type2Message t2m = new DavMailNTLMEngineImpl.Type2Message(challenge);
 
-        LOGGER.debug("generateType3Msg type2Flags " + t2m.getFlags() + " target='" + t2m.getTarget() + " username='" + username + "'");
+        LOGGER.debug("generateType3Msg type2Flags=" + t2m.getFlags() + " target='" + t2m.getTarget() + "' username='" + username + "' domain='" + domain + "' workstation='" + workstation + "'");
 
-        return getType3Message(
+        String type3Message = getType3Message(
                 username,
                 password,
                 workstation,
@@ -1868,6 +1875,10 @@ final class DavMailNTLMEngineImpl implements NTLMEngine {
                 peerServerCertificate,
                 type1MessageBytes,
                 type2MessageBytes);
+        if (LOGGER.isDebugEnabled()) {
+            LOGGER.debug(NTLMMessageDecoder.decode(type3Message));
+        }
+        return type3Message;
     }
 
 }
