@@ -32,6 +32,7 @@ import org.apache.http.auth.NTCredentials;
 import org.apache.http.client.CredentialsProvider;
 import org.apache.http.client.HttpResponseException;
 import org.apache.http.client.config.AuthSchemes;
+import org.apache.http.client.config.CookieSpecs;
 import org.apache.http.client.config.RequestConfig;
 import org.apache.http.client.methods.CloseableHttpResponse;
 import org.apache.http.client.methods.HttpRequestBase;
@@ -276,7 +277,13 @@ public class HttpClientAdapter implements Closeable {
 
     private Registry<AuthSchemeProvider> getAuthSchemeRegistry() {
         final RegistryBuilder<AuthSchemeProvider> registryBuilder = RegistryBuilder.create();
-        registryBuilder.register(AuthSchemes.NTLM, new DavMailNTLMSchemeFactory())
+        AuthSchemeProvider ntlmSchemeProvider;
+        if (Settings.getBooleanProperty("davmail.enableJcifs", true)) {
+            ntlmSchemeProvider = new JCIFSNTLMSchemeFactory();
+        } else {
+            ntlmSchemeProvider = new DavMailNTLMSchemeFactory();
+        }
+        registryBuilder.register(AuthSchemes.NTLM, ntlmSchemeProvider)
                 .register(AuthSchemes.BASIC, new BasicSchemeFactory())
                 .register(AuthSchemes.DIGEST, new DigestSchemeFactory());
         if (Settings.getBooleanProperty("davmail.enableKerberos")) {
@@ -297,6 +304,7 @@ public class HttpClientAdapter implements Closeable {
             authSchemes.add(AuthSchemes.DIGEST);
         }
         return RequestConfig.custom()
+                .setCookieSpec(CookieSpecs.STANDARD)
                 // socket connect timeout
                 .setConnectTimeout(Settings.getIntProperty("davmail.exchange.connectionTimeout", 10) * 1000)
                 // inactivity timeout
@@ -321,6 +329,9 @@ public class HttpClientAdapter implements Closeable {
                 // separate domain from username in credentials
                 domain = userid.substring(0, backSlashIndex);
                 userid = userid.substring(backSlashIndex + 1);
+            } else if (userid.contains("@")) {
+                // no need for domain name with userPrincipalName
+                domain = "";
             } else {
                 domain = Settings.getProperty("davmail.defaultDomain", "");
             }
