@@ -27,6 +27,7 @@ import davmail.exchange.ExchangeSessionFactory;
 import davmail.ui.tray.DavGatewayTray;
 import davmail.util.IOUtil;
 
+import javax.mail.MessagingException;
 import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
 import javax.mail.internet.MimeMessage;
@@ -64,7 +65,7 @@ public class SmtpConnection extends AbstractConnection {
         try {
             ExchangeSessionFactory.checkConfig();
             sendClient("220 DavMail " + DavGateway.getCurrentVersion() + " SMTP ready at " + new Date());
-            for (; ;) {
+            for (; ; ) {
                 line = readClient();
                 // unable to read line, connection closed ?
                 if (line == null) {
@@ -90,7 +91,7 @@ public class SmtpConnection extends AbstractConnection {
                     } else if ("NOOP".equalsIgnoreCase(command)) {
                         sendClient("250 OK");
                     } else if ("EHLO".equalsIgnoreCase(command)) {
-                        sendClient("250-" + tokens.nextToken());
+                        sendClient("250-davmail");
                         // inform server that AUTH is supported
                         // actually it is mandatory (only way to get credentials)
                         sendClient("250-AUTH LOGIN PLAIN");
@@ -106,7 +107,7 @@ public class SmtpConnection extends AbstractConnection {
                                 authenticate();
                             } else if ("LOGIN".equalsIgnoreCase(authType)) {
                                 if (tokens.hasMoreTokens()) {
-                                    // user name sent on auth line
+                                    // username sent on auth line
                                     userName = IOUtil.decodeBase64AsString(tokens.nextToken());
                                     sendClient("334 " + IOUtil.encodeBase64AsString("Password:"));
                                     state = State.PASSWORD;
@@ -157,13 +158,7 @@ public class SmtpConnection extends AbstractConnection {
 
                             try {
                                 // read message in buffer
-                                ByteArrayOutputStream baos = new ByteArrayOutputStream();
-                                DoubleDotInputStream doubleDotInputStream = new DoubleDotInputStream(in);
-                                int b;
-                                while ((b = doubleDotInputStream.read()) >= 0) {
-                                    baos.write(b);
-                                }
-                                MimeMessage mimeMessage = new MimeMessage(null, new SharedByteArrayInputStream(baos.toByteArray()));
+                                MimeMessage mimeMessage = getMimeMessage();
                                 session.sendMessage(recipients, mimeMessage);
                                 state = State.AUTHENTICATED;
                                 sendClient("250 Queued mail for delivery");
@@ -209,7 +204,7 @@ public class SmtpConnection extends AbstractConnection {
             DavGatewayTray.log(e);
             try {
                 // append a line feed to avoid thunderbird message drop
-                sendClient("421 " + ((e.getMessage() == null) ? e : e.getMessage())+"\n");
+                sendClient("421 " + ((e.getMessage() == null) ? e : e.getMessage()) + "\n");
             } catch (IOException e2) {
                 DavGatewayTray.debug(new BundleMessage("LOG_EXCEPTION_SENDING_ERROR_TO_CLIENT"), e2);
             }
@@ -219,6 +214,16 @@ public class SmtpConnection extends AbstractConnection {
         DavGatewayTray.resetIcon();
     }
 
+    private MimeMessage getMimeMessage() throws IOException, MessagingException {
+        ByteArrayOutputStream baos = new ByteArrayOutputStream();
+        DoubleDotInputStream doubleDotInputStream = new DoubleDotInputStream(in);
+        int b;
+        while ((b = doubleDotInputStream.read()) >= 0) {
+            baos.write(b);
+        }
+        return new MimeMessage(null, new SharedByteArrayInputStream(baos.toByteArray()));
+    }
+
     /**
      * Create authenticated session with Exchange server
      *
@@ -253,10 +258,10 @@ public class SmtpConnection extends AbstractConnection {
     protected void decodeCredentials(String encodedCredentials) throws IOException {
         String decodedCredentials = IOUtil.decodeBase64AsString(encodedCredentials);
         int startIndex = decodedCredentials.indexOf((char) 0);
-        if (startIndex >=0) {
-            int endIndex = decodedCredentials.indexOf((char) 0, startIndex+1);
-            if (endIndex >=0) {
-                userName = decodedCredentials.substring(startIndex+1, endIndex);
+        if (startIndex >= 0) {
+            int endIndex = decodedCredentials.indexOf((char) 0, startIndex + 1);
+            if (endIndex >= 0) {
+                userName = decodedCredentials.substring(startIndex + 1, endIndex);
                 password = decodedCredentials.substring(endIndex + 1);
             } else {
                 throw new DavMailException("EXCEPTION_INVALID_CREDENTIALS");
