@@ -412,6 +412,15 @@ public final class StringUtil {
      * @return escaped value
      */
     public static String davSearchEncode(String value) {
+        return escapeQuotes(value);
+    }
+
+    /**
+     * Escape quotes for DAV and graph filters.
+     * @param value input value
+     * @return quoted result
+     */
+    public static String escapeQuotes(String value) {
         String result = value;
         if (result.indexOf('\'') >= 0) {
             result = APOS_PATTERN.matcher(result).replaceAll("''");
@@ -532,4 +541,34 @@ public final class StringUtil {
         return result;
     }
 
+    /**
+     * Decode the folder name with _xF8FF_ or _x003E_ characters.
+     * @param folderName encoded folder name
+     * @return decoded folder name
+     */
+    public static String decodeFolderName(String folderName) {
+        if (folderName.contains("_xF8FF_")) {
+            return folderName.replace("_xF8FF_", "/");
+        }
+        if (folderName.contains("_x003E_")) {
+            return folderName.replace("_x003E_", ">");
+        }
+        return folderName;
+    }
+
+    /**
+     * folderName may contain / or > characters, encode them.
+     * @param folderName folder name to encode
+     * @return encoded folder name
+     */
+    public static String encodeFolderName(String folderName) {
+        if (folderName.contains("/")) {
+            folderName = folderName.replace("/", "_xF8FF_");
+        }
+        if (folderName.contains(">")) {
+            folderName = folderName.replace(">", "_x003E_");
+        }
+        return folderName;
+    }
+
 }
