@@ -23,9 +23,7 @@ import davmail.util.IOUtil;
 import org.apache.commons.codec.binary.Base64;
 
 import java.io.*;
-import java.util.HashMap;
 import java.util.List;
-import java.util.Map;
 import java.util.UUID;
 
 /**
@@ -118,7 +116,7 @@ public class TestExchangeSessionContact extends AbstractExchangeSessionTestCase
         assertEquals("middlename", contact.get("middlename"));
         assertEquals("personaltitle", contact.get("personaltitle"));
         assertEquals("namesuffix", contact.get("namesuffix"));
-        assertNotNull("lastmodified");
+        assertNotNull(contact.get("lastmodified"));
         assertEquals("nickname", contact.get("nickname"));
 
         assertEquals("mobile", contact.get("mobile"));
@@ -202,7 +200,7 @@ public class TestExchangeSessionContact extends AbstractExchangeSessionTestCase
         assertNull(contact.get("middlename"));
         assertNull(contact.get("personaltitle"));
         assertNull(contact.get("namesuffix"));
-        assertNotNull("lastmodified");
+        assertNotNull(contact.get("lastmodified"));
         assertNull(contact.get("nickname"));
 
         assertNull(contact.get("mobile"));
@@ -632,4 +630,37 @@ public class TestExchangeSessionContact extends AbstractExchangeSessionTestCase
         ExchangeSession.ItemResult result = session.createOrUpdateContact("testcontactfolder", itemName, itemBody, null, null);
         assertEquals(201, result.status);
     }
+
+    public void testGetAllContacts() throws IOException {
+        //session.getAllContacts("contacts");
+        List<ExchangeSession.Contact> contacts = session.searchContacts("contacts", ExchangeSession.CONTACT_ATTRIBUTES, session.isEqualTo("outlookmessageclass", "IPM.Contact"), 0);
+        //Settings.setLoggingLevel("httpclient.wire", Level.DEBUG);
+        for (ExchangeSession.Contact contact: contacts) {
+            ExchangeSession.Item item = session.getItem("contacts", contact.getName());
+            System.out.println((item).getBody());
+        }
+    }
+
+    public void testGetAllDistributionLists() throws IOException {
+        List<ExchangeSession.Contact> contacts = session.searchContacts("contacts", ExchangeSession.CONTACT_ATTRIBUTES, session.isEqualTo("outlookmessageclass", "IPM.DistList"), 0);
+        //Settings.setLoggingLevel("httpclient.wire", Level.DEBUG);
+        for (ExchangeSession.Contact contact: contacts) {
+            ExchangeSession.Item item = session.getItem("contacts", contact.getName());
+            System.out.println((item).getBody());
+        }
+    }
+
+    public void testMultilineProperty() {
+        VCardWriter vCardWriter = new VCardWriter();
+        vCardWriter.appendProperty("NOTE", "multi line \r\n with crlf");
+        // should drop CR and convert LF to \\n
+        assertEquals("NOTE:multi line \\n with crlf\r\n", vCardWriter.toString());
+    }
+
+    public void testMultiValueMultilineProperty() {
+        VCardWriter vCardWriter = new VCardWriter();
+        vCardWriter.appendProperty("ADR", "value","multi line \r\n with crlf");
+        // should drop CR and convert LF to \\n
+        assertEquals("ADR:value;multi line \\n with crlf\r\n", vCardWriter.toString());
+    }
 }
